==> redux-inputs-2.6.0.tgz: package/esm/reducers/index.js <==
import _objectSpread from "@babel/runtime/helpers/objectSpread";
import _mapValues from 'lodash/mapValues';
import _forEach from 'lodash/forEach';
import _omit from 'lodash/omit';
import invariant from 'invariant';
import { REDUX_MOUNT_POINT, getReduxMountPoint } from '../util/mountPoint';
import { SET_INPUT } from '../actions/actionTypes';

function getDefaultInputState(config) {
  return {
    value: config.defaultValue,
    pristine: true
  };
}

export function getDefaultInputs(inputConfig) {
  return _mapValues(_omit(inputConfig, REDUX_MOUNT_POINT), getDefaultInputState);
}

function _matchesReduxMountPoint(inputConfig, action) {
  return getReduxMountPoint(inputConfig) === (action.meta && action.meta.reduxMountPoint);
}

function _syncStateWithInputConfig(inputConfig, state) {
  var otherInputs = {};
  var nsync = true;

  _forEach(inputConfig, function (config, key) {
    if (key !== REDUX_MOUNT_POINT && typeof state[key] === 'undefined') {
      otherInputs[key] = getDefaultInputState(config);
      nsync = false;
    }
  });

  return nsync ? state : _objectSpread({}, otherInputs, state);
}

export function createInputsReducer(inputConfig) {
  invariant(inputConfig, '[redux-inputs]: inputConfig must be defined');
  return function () {
    var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : getDefaultInputs(inputConfig);
    var action = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

    if (_matchesReduxMountPoint(inputConfig, action)) {
      switch (action.type) {
        case SET_INPUT:
          return _objectSpread({}, state, action.payload);
      }
    }

    return _syncStateWithInputConfig(inputConfig, state);
  };
}

==> redux-inputs-2.7.0.tgz: package/esm/reducers/index.js <==
import _objectSpread from "@babel/runtime/helpers/esm/objectSpread2";
import _mapValues from 'lodash/mapValues';
import _forEach from 'lodash/forEach';
import _omit from 'lodash/omit';
import invariant from 'invariant';
import { REDUX_MOUNT_POINT, getReduxMountPoint } from '../util/mountPoint';
import { SET_INPUT } from '../actions/actionTypes';

function getDefaultInputState(config) {
  return {
    value: config.defaultValue,
    pristine: true
  };
}

export function getDefaultInputs(inputConfig) {
  return _mapValues(_omit(inputConfig, REDUX_MOUNT_POINT), getDefaultInputState);
}

function _matchesReduxMountPoint(inputConfig, action) {
  return getReduxMountPoint(inputConfig) === (action.meta && action.meta.reduxMountPoint);
}

function _syncStateWithInputConfig(inputConfig, state) {
  var otherInputs = {};
  var nsync = true;

  _forEach(inputConfig, function (config, key) {
    if (key !== REDUX_MOUNT_POINT && typeof state[key] === 'undefined') {
      otherInputs[key] = getDefaultInputState(config);
      nsync = false;
    }
  });

  return nsync ? state : _objectSpread({}, otherInputs, {}, state);
}

export function createInputsReducer(inputConfig) {
  invariant(inputConfig, '[redux-inputs]: inputConfig must be defined');
  return function () {
    var state = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : getDefaultInputs(inputConfig);
    var action = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};

    if (_matchesReduxMountPoint(inputConfig, action)) {
      switch (action.type) {
        case SET_INPUT:
          return _objectSpread({}, state, {}, action.payload);
      }
    }

    return _syncStateWithInputConfig(inputConfig, state);
  };
}
